@@ -14,10 +14,9 @@ import pytest
 from cleo.testers.command_tester import CommandTester
 from packaging.utils import canonicalize_name
 
+from poetry.console.application import Application
 from poetry.console.commands.init import InitCommand
 from poetry.repositories import RepositoryPool
-from poetry.utils._compat import decode
-from tests.helpers import PoetryTestApplication
 from tests.helpers import get_package
 
 
@@ -30,17 +29,17 @@ if TYPE_CHECKING:
 
     from poetry.config.config import Config
     from poetry.poetry import Poetry
+    from tests.helpers import PoetryTestApplication
     from tests.helpers import TestRepository
     from tests.types import FixtureDirGetter
 
 
 @pytest.fixture
 def source_dir(tmp_path: Path) -> Iterator[Path]:
-    cwd = os.getcwd()
-
+    cwd = Path.cwd()
     try:
-        os.chdir(str(tmp_path))
-        yield Path(tmp_path.as_posix())
+        os.chdir(tmp_path)
+        yield tmp_path
     finally:
         os.chdir(cwd)
 
@@ -56,8 +55,7 @@ def patches(mocker: MockerFixture, source_dir: Path, repo: TestRepository) -> No
 
 @pytest.fixture
 def tester(patches: None) -> CommandTester:
-    # we need a test application without poetry here.
-    app = PoetryTestApplication(None)
+    app = Application()
     return CommandTester(app.find("init"))
 
 
@@ -97,7 +95,7 @@ python = "~2.7 || ^3.6"
 
 def test_basic_interactive(
     tester: CommandTester, init_basic_inputs: str, init_basic_toml: str
-):
+) -> None:
     tester.execute(inputs=init_basic_inputs)
     assert init_basic_toml in tester.io.fetch_output()
 
@@ -108,8 +106,9 @@ def test_noninteractive(
     poetry: Poetry,
     repo: TestRepository,
     tmp_path: Path,
-):
+) -> None:
     command = app.find("init")
+    assert isinstance(command, InitCommand)
     command._pool = poetry.pool
 
     repo.add_package(get_package("pytest", "3.6.0"))
@@ -130,7 +129,9 @@ def test_noninteractive(
     assert 'pytest = "^3.6.0"' in toml_content
 
 
-def test_interactive_with_dependencies(tester: CommandTester, repo: TestRepository):
+def test_interactive_with_dependencies(
+    tester: CommandTester, repo: TestRepository
+) -> None:
     repo.add_package(get_package("django-pendulum", "0.1.6-pre4"))
     repo.add_package(get_package("pendulum", "2.0.0"))
     repo.add_package(get_package("pytest", "3.6.0"))
@@ -185,7 +186,7 @@ pytest = "^3.6.0"
 # Regression test for https://github.com/python-poetry/poetry/issues/2355
 def test_interactive_with_dependencies_and_no_selection(
     tester: CommandTester, repo: TestRepository
-):
+) -> None:
     repo.add_package(get_package("django-pendulum", "0.1.6-pre4"))
     repo.add_package(get_package("pendulum", "2.0.0"))
     repo.add_package(get_package("pytest", "3.6.0"))
@@ -226,7 +227,7 @@ python = "~2.7 || ^3.6"
     assert expected in tester.io.fetch_output()
 
 
-def test_empty_license(tester: CommandTester):
+def test_empty_license(tester: CommandTester) -> None:
     inputs = [
         "my-package",  # Package name
         "1.2.3",  # Version
@@ -256,7 +257,9 @@ python = "^{python}"
     assert expected in tester.io.fetch_output()
 
 
-def test_interactive_with_git_dependencies(tester: CommandTester, repo: TestRepository):
+def test_interactive_with_git_dependencies(
+    tester: CommandTester, repo: TestRepository
+) -> None:
     repo.add_package(get_package("pendulum", "2.0.0"))
     repo.add_package(get_package("pytest", "3.6.0"))
 
@@ -326,7 +329,8 @@ _generate_choice_list_packages_params: list[list[Package]] = [
 
 @pytest.fixture(params=_generate_choice_list_packages_params)
 def _generate_choice_list_packages(request: FixtureRequest) -> list[Package]:
-    return request.param
+    packages: list[Package] = request.param
+    return packages
 
 
 @pytest.mark.parametrize("package_name", ["flask", "Flask", "flAsK"])
@@ -334,8 +338,9 @@ def test_generate_choice_list(
     tester: CommandTester,
     package_name: str,
     _generate_choice_list_packages: list[Package],
-):
+) -> None:
     init_command = tester.command
+    assert isinstance(init_command, InitCommand)
 
     packages = _generate_choice_list_packages
     choices = init_command._generate_choice_list(
@@ -347,7 +352,7 @@ def test_generate_choice_list(
 
 def test_interactive_with_git_dependencies_with_reference(
     tester: CommandTester, repo: TestRepository
-):
+) -> None:
     repo.add_package(get_package("pendulum", "2.0.0"))
     repo.add_package(get_package("pytest", "3.6.0"))
 
@@ -393,7 +398,7 @@ pytest = "^3.6.0"
 
 def test_interactive_with_git_dependencies_and_other_name(
     tester: CommandTester, repo: TestRepository
-):
+) -> None:
     repo.add_package(get_package("pendulum", "2.0.0"))
     repo.add_package(get_package("pytest", "3.6.0"))
 
@@ -442,7 +447,7 @@ def test_interactive_with_directory_dependency(
     repo: TestRepository,
     source_dir: Path,
     fixture_dir: FixtureDirGetter,
-):
+) -> None:
     repo.add_package(get_package("pendulum", "2.0.0"))
     repo.add_package(get_package("pytest", "3.6.0"))
 
@@ -493,7 +498,7 @@ def test_interactive_with_directory_dependency_and_other_name(
     repo: TestRepository,
     source_dir: Path,
     fixture_dir: FixtureDirGetter,
-):
+) -> None:
     repo.add_package(get_package("pendulum", "2.0.0"))
     repo.add_package(get_package("pytest", "3.6.0"))
 
@@ -545,7 +550,7 @@ def test_interactive_with_file_dependency(
     repo: TestRepository,
     source_dir: Path,
     fixture_dir: FixtureDirGetter,
-):
+) -> None:
     repo.add_package(get_package("pendulum", "2.0.0"))
     repo.add_package(get_package("pytest", "3.6.0"))
 
@@ -594,7 +599,7 @@ pytest = "^3.6.0"
 
 def test_interactive_with_wrong_dependency_inputs(
     tester: CommandTester, repo: TestRepository
-):
+) -> None:
     inputs = [
         "my-package",  # Package name
         "1.2.3",  # Version
@@ -638,7 +643,7 @@ pytest = "3.6.0"
     assert expected in tester.io.fetch_output()
 
 
-def test_python_option(tester: CommandTester):
+def test_python_option(tester: CommandTester) -> None:
     inputs = [
         "my-package",  # Package name
         "1.2.3",  # Version
@@ -668,7 +673,7 @@ python = "~2.7 || ^3.6"
     assert expected in tester.io.fetch_output()
 
 
-def test_predefined_dependency(tester: CommandTester, repo: TestRepository):
+def test_predefined_dependency(tester: CommandTester, repo: TestRepository) -> None:
     repo.add_package(get_package("pendulum", "2.0.0"))
 
     inputs = [
@@ -704,7 +709,7 @@ pendulum = "^2.0.0"
 
 def test_predefined_and_interactive_dependencies(
     tester: CommandTester, repo: TestRepository
-):
+) -> None:
     repo.add_package(get_package("pendulum", "2.0.0"))
     repo.add_package(get_package("pyramid", "1.10"))
 
@@ -745,7 +750,7 @@ python = "~2.7 || ^3.6"
     assert 'pyramid = "^1.10"' in output
 
 
-def test_predefined_dev_dependency(tester: CommandTester, repo: TestRepository):
+def test_predefined_dev_dependency(tester: CommandTester, repo: TestRepository) -> None:
     repo.add_package(get_package("pytest", "3.6.0"))
 
     inputs = [
@@ -784,7 +789,7 @@ pytest = "^3.6.0"
 
 def test_predefined_and_interactive_dev_dependencies(
     tester: CommandTester, repo: TestRepository
-):
+) -> None:
     repo.add_package(get_package("pytest", "3.6.0"))
     repo.add_package(get_package("pytest-requests", "0.2.0"))
 
@@ -830,7 +835,7 @@ pytest-requests = "^0.2.0"
     assert 'pytest = "^3.6.0"' in output
 
 
-def test_predefined_all_options(tester: CommandTester, repo: TestRepository):
+def test_predefined_all_options(tester: CommandTester, repo: TestRepository) -> None:
     repo.add_package(get_package("pendulum", "2.0.0"))
     repo.add_package(get_package("pytest", "3.6.0"))
 
@@ -877,8 +882,10 @@ pytest = "^3.6.0"
     assert expected in output
 
 
-def test_add_package_with_extras_and_whitespace(tester: CommandTester):
-    result = tester.command._parse_requirements(["databases[postgresql, sqlite]"])
+def test_add_package_with_extras_and_whitespace(tester: CommandTester) -> None:
+    command = tester.command
+    assert isinstance(command, InitCommand)
+    result = command._parse_requirements(["databases[postgresql, sqlite]"])
 
     assert result[0]["name"] == "databases"
     assert len(result[0]["extras"]) == 2
@@ -891,13 +898,13 @@ def test_init_existing_pyproject_simple(
     source_dir: Path,
     init_basic_inputs: str,
     init_basic_toml: str,
-):
+) -> None:
     pyproject_file = source_dir / "pyproject.toml"
     existing_section = """
 [tool.black]
 line-length = 88
 """
-    pyproject_file.write_text(decode(existing_section))
+    pyproject_file.write_text(existing_section)
     tester.execute(inputs=init_basic_inputs)
     assert f"{existing_section}\n{init_basic_toml}" in pyproject_file.read_text()
 
@@ -909,14 +916,12 @@ def test_init_existing_pyproject_consistent_linesep(
     init_basic_inputs: str,
     init_basic_toml: str,
     linesep: str,
-):
+) -> None:
     pyproject_file = source_dir / "pyproject.toml"
     existing_section = """
 [tool.black]
 line-length = 88
-""".replace(
-        "\n", linesep
-    )
+""".replace("\n", linesep)
     with open(pyproject_file, "w", newline="") as f:
         f.write(existing_section)
     tester.execute(inputs=init_basic_inputs)
@@ -931,13 +936,13 @@ def test_init_non_interactive_existing_pyproject_add_dependency(
     source_dir: Path,
     init_basic_inputs: str,
     repo: TestRepository,
-):
+) -> None:
     pyproject_file = source_dir / "pyproject.toml"
     existing_section = """
 [tool.black]
 line-length = 88
 """
-    pyproject_file.write_text(decode(existing_section))
+    pyproject_file.write_text(existing_section)
 
     repo.add_package(get_package("foo", "1.19.2"))
 
@@ -969,14 +974,14 @@ foo = "^1.19.2"
 
 def test_init_existing_pyproject_with_build_system_fails(
     tester: CommandTester, source_dir: Path, init_basic_inputs: str
-):
+) -> None:
     pyproject_file = source_dir / "pyproject.toml"
     existing_section = """
 [build-system]
 requires = ["setuptools >= 40.6.0", "wheel"]
 build-backend = "setuptools.build_meta"
 """
-    pyproject_file.write_text(decode(existing_section))
+    pyproject_file.write_text(existing_section)
     tester.execute(inputs=init_basic_inputs)
     assert (
         tester.io.fetch_error().strip()
@@ -999,14 +1004,14 @@ build-backend = "setuptools.build_meta"
         "   foo 2.0  ",
     ],
 )
-def test__validate_package_valid(name: str | None):
+def test_validate_package_valid(name: str | None) -> None:
     assert InitCommand._validate_package(name) == name
 
 
 @pytest.mark.parametrize(
     "name", ["foo bar 2.0", "   foo bar 2.0   ", "foo bar foobar 2.0"]
 )
-def test__validate_package_invalid(name: str):
+def test_validate_package_invalid(name: str) -> None:
     with pytest.raises(ValueError):
         assert InitCommand._validate_package(name)
 
@@ -1025,7 +1030,7 @@ def test_package_include(
     tester: CommandTester,
     package_name: str,
     include: str | None,
-):
+) -> None:
     tester.execute(
         inputs="\n".join(
             (
@@ -1042,10 +1047,7 @@ def test_package_include(
         ),
     )
 
-    if include is None:
-        packages = ""
-    else:
-        packages = f'packages = [{{include = "{include}"}}]\n'
+    packages = "" if include is None else f'packages = [{{include = "{include}"}}]\n'
 
     expected = (
         f"[tool.poetry]\n"
@@ -1076,7 +1078,7 @@ def test_respect_prefer_active_on_init(
     mocker: MockerFixture,
     tester: CommandTester,
     source_dir: Path,
-):
+) -> None:
     from poetry.utils.env import GET_PYTHON_VERSION_ONELINER
 
     orig_check_output = subprocess.check_output
@@ -1085,7 +1087,8 @@ def test_respect_prefer_active_on_init(
         if GET_PYTHON_VERSION_ONELINER in cmd:
             return "1.1.1"
 
-        return orig_check_output(cmd, *_, **__)
+        result: str = orig_check_output(cmd, *_, **__)
+        return result
 
     mocker.patch("subprocess.check_output", side_effect=mock_check_output)
 
